Package: soiltestcorr
Title: Soil Test Correlation and Calibration
Version: 2.2.1
Date: 2024-06-30
Authors@R: c(
    person(given = "Adrian A.", family = "Correndo",
             email = "acorrend@uoguelph.ca", role = c("aut", "cre", "cph"),comment = c(ORCID = "0000-0002-4172-289X")),
    person(given = "Austin", family = "Pearce",
             email = "awpearc2@ncsu.edu", role = "aut",comment = c(ORCID = "0000-0002-2541-896X")),
    person(given = "Fernando", family = "Miguez",
             email = "femiguez@iastate.edu", role = "ctb",comment = c(ORCID = "0000-0002-4627-8329")),
    person(given = "Deanna", family = "Osmond",
             email = "deanna_osmond@ncsu.edu", role = "aut",comment = c(ORCID = "0000-0002-6336-8318")),
    person("Ignacio A.", "Ciampitti", email = "ciampitti@ksu.edu", role = c("aut"), comment = c(ORCID = "0000-0001-9619-5129")) )
Description: A compilation of functions designed to assist users on the correlation analysis of crop yield and soil test values. Functions to estimate crop response patterns to soil nutrient availability and critical soil test values using various approaches such as: 1) the modified arcsine-log calibration curve (Correndo et al. (2017) <doi:10.1071/CP16444>); 2) the graphical Cate-Nelson quadrants analysis (Cate & Nelson (1965)), 3) the statistical Cate-Nelson quadrants analysis (Cate & Nelson (1971) <doi:10.2136/sssaj1971.03615995003500040048x>), 4) the linear-plateau regression (Anderson & Nelson (1975) <doi:10.2307/2529422>), 5) the quadratic-plateau regression (Bullock & Bullock (1994) <doi:10.2134/agronj1994.00021962008600010033x>), and 6) the Mitscherlich-type exponential regression (Melsted & Peck (1977) <doi:10.2134/asaspecpub29.c1>). The package development stemmed from ongoing work with the Fertilizer Recommendation Support Tool (FRST) and Feed the Future Innovation Lab for Collaborative Research on Sustainable Intensification (SIIL) projects. 
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown, testthat
Imports: stats, dplyr, rlang, tidyr, utils, purrr, data.table, ggplot2,
        ggpp, nlstools, minpack.lm, modelr, nlraa, AICcmodavg, smatr
Depends: R (>= 3.6.0)
LazyData: true
VignetteBuilder: knitr
URL: https://adriancorrendo.github.io/soiltestcorr/,
        https://soiltestfrst.org/,
        https://www.siildigitalagconsortium.com/
BugReports: https://github.com/adriancorrendo/soiltestcorr/issues
NeedsCompilation: no
Packaged: 2024-06-30 15:25:01 UTC; acorrend
Author: Adrian A. Correndo [aut, cre, cph]
    (<https://orcid.org/0000-0002-4172-289X>),
  Austin Pearce [aut] (<https://orcid.org/0000-0002-2541-896X>),
  Fernando Miguez [ctb] (<https://orcid.org/0000-0002-4627-8329>),
  Deanna Osmond [aut] (<https://orcid.org/0000-0002-6336-8318>),
  Ignacio A. Ciampitti [aut] (<https://orcid.org/0000-0001-9619-5129>)
Maintainer: Adrian A. Correndo <acorrend@uoguelph.ca>
Repository: CRAN
Date/Publication: 2024-07-01 06:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:59:53 UTC; unix
