# Generated by roxygen2: do not edit by hand

export(SS_LP)
export(SS_QP)
export(boot_cn_1965)
export(boot_cn_1971)
export(boot_linear_plateau)
export(boot_mitscherlich)
export(boot_mod_alcc)
export(boot_quadratic_plateau)
export(cate_nelson_1965)
export(cate_nelson_1971)
export(linear_plateau)
export(logLik_alcc)
export(mits_formula_1)
export(mits_formula_2)
export(mits_formula_3)
export(mitscherlich)
export(mod_alcc)
export(quadratic_plateau)
importFrom(AICcmodavg,AICc)
importFrom(data.table,between)
importFrom(dplyr,"%>%")
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,slice_sample)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rug)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,rel)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_shape_manual)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(ggpp,geom_grob)
importFrom(minpack.lm,nlsLM)
importFrom(modelr,rmse)
importFrom(modelr,rsquare)
importFrom(nlraa,SSlinp)
importFrom(nlraa,SSquadp3xs)
importFrom(nlstools,confint2)
importFrom(nlstools,nlsResiduals)
importFrom(purrr,map)
importFrom(purrr,possibly)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,quo)
importFrom(smatr,sma)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,approx)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,lm)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,qt)
importFrom(stats,sd)
importFrom(stats,sortedXyData)
importFrom(tidyr,expand_grid)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,head)
