---
title: "Introduction"
author: Adrian Correndo & Austin Pearce 
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  # collapse = TRUE,
  comment = "#>",
  fig.width=6, 
  fig.height=4
)
```

<img src="../man/figures/soiltestcorr_logo.png" align="right" height="200" style="float:right; height:200px;">

The `soiltestcorr` package is a collection of functions intended to contribute to reproducible correlation analysis between crop relative yield (RY) and soil test values (STV). The package development stemmed from ongoing work with the Fertilizer Recommendation Support Tool ([FRST](https://soiltestfrst.org/)) and the Feed the Future Innovation Lab for Collaborative Research on Sustainable Intensification ([SIIL](https://www.siildigitalagconsortium.com/)) projects. <br/> 

This tutorial will introduce and demonstrate the currently available functions. <br/>

## 1. Installation

You can install the latest CRAN version of `soiltestcorr` with: <br/>

``` r
install.packages("soiltestcorr")
```

Alternatively, you can install the development version of `soiltestcorr` from [GitHub](https://github.com/adriancorrendo/soiltestcorr) with:

``` r
# install.packages("devtools")
devtools::install_github("adriancorrendo/soiltestcorr")
```

```{r setup}
library(soiltestcorr)
```

Suggested packages are
```{r warning=FALSE, message=FALSE}
library(ggplot2) # Plots
library(dplyr) # Data wrangling
library(tidyr) # Data wrangling
library(purrr) # Mapping

```

## 2. Available models in `soiltestcorr`: <br/>

### 2.1. [Modified Arcsine-Log Calibration Curve](https://adriancorrendo.github.io/soiltestcorr/articles/mod_alcc_tutorial.html) <br/>

### 2.2. [Cate & Nelson (1965)](https://adriancorrendo.github.io/soiltestcorr/articles/cate_nelson_1965_tutorial.html) <br/>

### 2.3. [Cate & Nelson (1971)](https://adriancorrendo.github.io/soiltestcorr/articles/cate_nelson_1971_tutorial.html) <br/>

### 2.4. [Linear-plateau](https://adriancorrendo.github.io/soiltestcorr/articles/linear_plateau_tutorial.html) <br/>

### 2.5. [Quadratic-plateau](https://adriancorrendo.github.io/soiltestcorr/articles/quadratic_plateau_tutorial.html) <br/>

### 2.6. [Mitscherlich](https://adriancorrendo.github.io/soiltestcorr/articles/mitscherlich_tutorial.html) <br/>


## 3. Publication in `SoftwareX Journal`: <br/>

[https://doi.org/10.1016/j.softx.2022.101275](https://doi.org/10.1016/j.softx.2022.101275) <br/>

## 4. Shinyapp: <br/>

[https://ciampittilab.shinyapps.io/soiltestcorr/](https://ciampittilab.shinyapps.io/soiltestcorr/) <br/>
